==> monaco-vscode-user-data-profile-service-override-12.0.0.tgz: package/vscode/src/vs/platform/userDataProfile/common/userDataProfileStorageService.js <==

import { __decorate, __param } from 'vscode/external/tslib/tslib.es6';
import { Disposable, DisposableMap, toDisposable, isDisposable } from 'vscode/vscode/vs/base/common/lifecycle';
import { Storage } from 'vscode/vscode/vs/base/parts/storage/common/storage';
import { StorageScope, StorageTarget, AbstractStorageService } from 'vscode/vscode/vs/platform/storage/common/storage';
import { IStorageService } from 'vscode/vscode/vs/platform/storage/common/storage.service';
import 'vscode/vscode/vs/base/common/event';
import 'vscode/vscode/vs/platform/userDataProfile/common/userDataProfile';

let AbstractUserDataProfileStorageService = class AbstractUserDataProfileStorageService extends Disposable {
    constructor(persistStorages, storageService) {
        super();
        this.storageService = storageService;
        if (persistStorages) {
            this.storageServicesMap = this._register(( new DisposableMap()));
        }
    }
    async readStorageData(profile) {
        return this.withProfileScopedStorageService(profile, async (storageService) => this.getItems(storageService));
    }
    async updateStorageData(profile, data, target) {
        return this.withProfileScopedStorageService(profile, async (storageService) => this.writeItems(storageService, data, target));
    }
    async withProfileScopedStorageService(profile, fn) {
        if (this.storageService.hasScope(profile)) {
            return fn(this.storageService);
        }
        let storageService = this.storageServicesMap?.get(profile.id);
        if (!storageService) {
            storageService = ( new StorageService(this.createStorageDatabase(profile)));
            this.storageServicesMap?.set(profile.id, storageService);
            try {
                await storageService.initialize();
            }
            catch (error) {
                if (this.storageServicesMap?.has(profile.id)) {
                    this.storageServicesMap.deleteAndDispose(profile.id);
                }
                else {
                    storageService.dispose();
                }
                throw error;
            }
        }
        try {
            const result = await fn(storageService);
            await storageService.flush();
            return result;
        }
        finally {
            if (!this.storageServicesMap?.has(profile.id)) {
                storageService.dispose();
            }
        }
    }
    getItems(storageService) {
        const result = ( new Map());
        const populate = (target) => {
            for (const key of ( storageService.keys(StorageScope.PROFILE, target))) {
                result.set(key, { value: storageService.get(key, StorageScope.PROFILE), target });
            }
        };
        populate(StorageTarget.USER);
        populate(StorageTarget.MACHINE);
        return result;
    }
    writeItems(storageService, items, target) {
        storageService.storeAll(( Array.from(items.entries()).map(([key, value]) => ({ key, value, scope: StorageScope.PROFILE, target }))), true);
    }
};
AbstractUserDataProfileStorageService = ( __decorate([
    ( __param(1, IStorageService))
], AbstractUserDataProfileStorageService));
class StorageService extends AbstractStorageService {
    constructor(profileStorageDatabase) {
        super({ flushInterval: 100 });
        this.profileStorageDatabase = profileStorageDatabase;
    }
    async doInitialize() {
        const profileStorageDatabase = await this.profileStorageDatabase;
        const profileStorage = ( new Storage(profileStorageDatabase));
        this._register(profileStorage.onDidChangeStorage(e => {
            this.emitDidChangeValue(StorageScope.PROFILE, e);
        }));
        this._register(toDisposable(() => {
            profileStorage.close();
            profileStorage.dispose();
            if (isDisposable(profileStorageDatabase)) {
                profileStorageDatabase.dispose();
            }
        }));
        this.profileStorage = profileStorage;
        return this.profileStorage.init();
    }
    getStorage(scope) {
        return scope === StorageScope.PROFILE ? this.profileStorage : undefined;
    }
    getLogDetails() { return undefined; }
    async switchToProfile() { }
    async switchToWorkspace() { }
    hasScope() { return false; }
}

export { AbstractUserDataProfileStorageService };

==> monaco-vscode-user-data-profile-service-override-17.0.0.tgz: package/vscode/src/vs/platform/userDataProfile/common/userDataProfileStorageService.js <==

import { __decorate, __param } from '@codingame/monaco-vscode-api/external/tslib/tslib.es6';
import { Disposable, DisposableMap, toDisposable, isDisposable } from '@codingame/monaco-vscode-api/vscode/vs/base/common/lifecycle';
import { Storage } from '@codingame/monaco-vscode-api/vscode/vs/base/parts/storage/common/storage';
import { StorageScope, StorageTarget, AbstractStorageService } from '@codingame/monaco-vscode-api/vscode/vs/platform/storage/common/storage';
import { IStorageService } from '@codingame/monaco-vscode-api/vscode/vs/platform/storage/common/storage.service';
import '@codingame/monaco-vscode-api/vscode/vs/base/common/event';
import '@codingame/monaco-vscode-api/vscode/vs/platform/userDataProfile/common/userDataProfile';

let AbstractUserDataProfileStorageService = class AbstractUserDataProfileStorageService extends Disposable {
    constructor(persistStorages, storageService) {
        super();
        this.storageService = storageService;
        if (persistStorages) {
            this.storageServicesMap = this._register(( new DisposableMap()));
        }
    }
    async readStorageData(profile) {
        return this.withProfileScopedStorageService(profile, async (storageService) => this.getItems(storageService));
    }
    async updateStorageData(profile, data, target) {
        return this.withProfileScopedStorageService(profile, async (storageService) => this.writeItems(storageService, data, target));
    }
    async withProfileScopedStorageService(profile, fn) {
        if (this.storageService.hasScope(profile)) {
            return fn(this.storageService);
        }
        let storageService = this.storageServicesMap?.get(profile.id);
        if (!storageService) {
            storageService = ( new StorageService(this.createStorageDatabase(profile)));
            this.storageServicesMap?.set(profile.id, storageService);
            try {
                await storageService.initialize();
            }
            catch (error) {
                if (this.storageServicesMap?.has(profile.id)) {
                    this.storageServicesMap.deleteAndDispose(profile.id);
                }
                else {
                    storageService.dispose();
                }
                throw error;
            }
        }
        try {
            const result = await fn(storageService);
            await storageService.flush();
            return result;
        }
        finally {
            if (!this.storageServicesMap?.has(profile.id)) {
                storageService.dispose();
            }
        }
    }
    getItems(storageService) {
        const result = ( new Map());
        const populate = (target) => {
            for (const key of ( storageService.keys(StorageScope.PROFILE, target))) {
                result.set(key, { value: storageService.get(key, StorageScope.PROFILE), target });
            }
        };
        populate(StorageTarget.USER);
        populate(StorageTarget.MACHINE);
        return result;
    }
    writeItems(storageService, items, target) {
        storageService.storeAll(( Array.from(items.entries()).map(([key, value]) => ({ key, value, scope: StorageScope.PROFILE, target }))), true);
    }
};
AbstractUserDataProfileStorageService = ( __decorate([
    ( __param(1, IStorageService))
], AbstractUserDataProfileStorageService));
class StorageService extends AbstractStorageService {
    constructor(profileStorageDatabase) {
        super({ flushInterval: 100 });
        this.profileStorageDatabase = profileStorageDatabase;
    }
    async doInitialize() {
        const profileStorageDatabase = await this.profileStorageDatabase;
        const profileStorage = ( new Storage(profileStorageDatabase));
        this._register(profileStorage.onDidChangeStorage(e => {
            this.emitDidChangeValue(StorageScope.PROFILE, e);
        }));
        this._register(toDisposable(() => {
            profileStorage.close();
            profileStorage.dispose();
            if (isDisposable(profileStorageDatabase)) {
                profileStorageDatabase.dispose();
            }
        }));
        this.profileStorage = profileStorage;
        return this.profileStorage.init();
    }
    getStorage(scope) {
        return scope === StorageScope.PROFILE ? this.profileStorage : undefined;
    }
    getLogDetails() { return undefined; }
    async switchToProfile() { }
    async switchToWorkspace() { }
    hasScope() { return false; }
}

export { AbstractUserDataProfileStorageService };
